@@ -1,5 +1,5 @@
 ##
-## $Release: 1.0.0 $
+## $Release: 1.0.2 $
 ## $Copyright: copyright(c) 2007-2011 kuwata-lab.com all rights reserved. $
 ## $License: MIT License $
 ##
@@ -29,7 +29,7 @@
    http://www.kuwata-lab.com/tenjin/pytenjin-examples.html
 """
 
-__version__  = "$Release: 1.0.0 $"[10:-2]
+__version__  = "$Release: 1.0.2 $"[10:-2]
 __license__  = "$License: MIT License $"[10:-2]
 __all__      = ('Template', 'Engine', )
 
@@ -278,7 +278,7 @@ def _dummy():
         return s
 
 helpers = create_module('tenjin.helpers', _dummy, sys=sys, re=re)
-helpers.__all__ = ['to_str', 'escape', 'echo', 'generate_tostrfunc',
+helpers.__all__ = ['to_str', 'escape', 'echo', 'new_cycle', 'generate_tostrfunc',
                    'start_capture', 'stop_capture', 'capture_as', 'captured_as',
                    'not_cached', 'echo_cached', 'cache_as',
                    '_p', '_P', '_decode_params',
@@ -374,7 +374,6 @@ def _dummy():
         return s.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;').replace('"', '&quot;').replace("'", '&#39;')   # 5.72
 
     escape_xml = escape_html   # for backward compatibility
-    escape     = escape_html
 
     def tagattr(name, expr, value=None, escape=True):
         """(experimental) Return ' name="value"' if expr is true value, else '' (empty string).
@@ -460,6 +459,7 @@ def _dummy():
 html = create_module('tenjin.html', _dummy, helpers=helpers, _escaped=escaped)
 helpers.escape = html.escape_html
 helpers.html = html   # for backward compatibility
+sys.modules['tenjin.helpers.html'] = html
 
 
 ##
