@@ -1,4 +1,5 @@
 import tenjin
 from tenjin.helpers import *
-engine = tenjin.Engine(path=['views'], escapefunc='cgi.escape', tostrfunc='str')
+import cgi
+engine = tenjin.Engine(path=['views'], escapefunc="cgi.escape", tostrfunc="str")
 print(engine.get_template('page.pyhtml').script)
